@@ -236,6 +236,14 @@ exit 1
                                         cwd=tmpdir)
         self.assertIn(tmpdir, out)
 
+    def test_process_input_with_string(self):
+        code = ';'.join(('import sys',
+                         'print(len(sys.stdin.readlines()))'))
+        args = [sys.executable, '-c', code]
+        input = "\n".join(['foo', 'bar', 'baz'])
+        stdout, stderr = processutils.execute(*args, process_input=input)
+        self.assertEqual("3", stdout.rstrip())
+
     def test_check_exit_code_list(self):
         processutils.execute('/usr/bin/env', 'sh', '-c', 'exit 101',
                              check_exit_code=(101, 102))
